Learn R Programming

XYomics (version 0.1.2)

categorize_sex_sc: Compute sex-specific differentially expressed genes (DEGs) per category

Description

Identifies male-specific, female-specific, sex-dimorphic, and sex-neutral DEGs from differential expression results.

Usage

categorize_sex_sc(
  male_degs,
  female_degs,
  target_fdr = 0.05,
  exclude_pval = 0.5,
  min_abs_logfc = 0.25
)

Value

Data frame containing categorized DEGs with associated statistics.

Arguments

male_degs

Data frame containing male differential expression results from one specific cell-type or bulk dataset.

female_degs

Data frame containing female differential expression results from one specific cell-type or bulk dataset.

target_fdr

Numeric. FDR threshold for significance.

exclude_pval

Numeric. P-value threshold for excluding genes in opposite sex.

min_abs_logfc

Numeric. Minimum absolute log2 fold change threshold.