Identifies differentially expressed genes (DEGs) separately for male and female samples within different cell types using the Seurat package. Compares gene expression between control and perturbed groups in each sex.
sex_stratified_analysis_sc(
seurat_obj,
sex_column = "sex",
phenotype_column = "status",
celltype_column = "cell_type",
sex_labels_vector = c("F", "M"),
min_logfc = 0.25,
phenotype_labels_vector = c("WT", "TG"),
method = "wilcox"
)A list with male and female DEGs results.
Seurat object containing the single-cell data.
Character. Column name in metadata for sex (default "sex").
Character. Column name in metadata for phenotype (default "status").
Character. Column name in metadata for cell type (default "cell_type").
Character vector of sex labels (default c("F","M")).
Numeric. Minimum absolute log fold change threshold (default 0.25).
Character vector of phenotype groups (default c("WT","TG")).
Character. Statistical test to use for differential expression (default "wilcox").